==> kipi-plugins-23.03.80.tar.xz: kipi-plugins-23.03.80/flickr/kipiplugin_flickr.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flickr/23
Name=Flickr/23
Name[bg]=Flickr/23
Name[ca]=Flickr/23
Name[ca@valencia]=Flickr/23
Name[cs]=Flickr/23
Name[da]=Flickr/23
Name[de]=Flickr/23
Name[el]=Flickr/23
Name[en_GB]=Flickr/23
Name[es]=Flickr/23
Name[et]=Flickr/23
Name[eu]=Flickr/23
Name[fi]=Flickr/23
Name[fr]=Flickr/23
Name[gl]=Flickr/23
Name[hu]=Flickr/23
Name[ia]=Flickr/23
Name[id]=Flickr/23
Name[is]=Flickr/23
Name[it]=Flickr/23
Name[ka]=Flickr/23
Name[ko]=Flickr/23
Name[nl]=Flickr/23
Name[nn]=Flickr/23
Name[pl]=Flickr/23
Name[pt]=Flickr/23
Name[pt_BR]=Flickr/23
Name[ro]=Flickr/23
Name[ru]=Flickr/23
Name[sk]=Flickr/23
Name[sl]=Flickr/23
Name[sv]=Flickr/23
Name[tr]=Flickr/23
Name[uk]=Flickr/23
Name[x-test]=xxFlickr/23xx
Name[zh_CN]=Flickr/23
Name[zh_TW]=Flickr/23
Comment=A tool to export images to remote Flickr and 23 web services.
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Flickr, 23.
Comment[ca]=Una eina per a exportar les imatges als serveis web remots de Flickr i 23.
Comment[ca@valencia]=Una eina per a exportar les imatges als serveis web remots de Flickr i 23.
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Flickr a 23.
Comment[da]=Et værktøj til at eksportere billeder til eksterne Flickr og 23 webtjenester.
Comment[de]=Ein Werkzeug, um Bilder zum Flickr- oder 23- Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στις απομακρυσμένες υπηρεσίες ιστού Flickr και 23.
Comment[en_GB]=A tool to export images to remote Flickr and 23 web services.
Comment[es]=Una herramienta para exportar imágenes a los servicios web remotos de Flickr y 23.
Comment[et]=Tööriist piltide eksportimiseks Flickri ja 23 veebiteenusesse.
Comment[eu]=Irudiak urruneko Flickr eta 23 web zerbitzuetara esportatzeko tresna bat.
Comment[fi]=Työkalu kuvien viemiseksi Flickr- tai 23-etäverkkopalveluun.
Comment[fr]=Un outil pour l'export d'images vers les services en ligne Flickr et 23.
Comment[gl]=Unha ferramenta para exportar imaxes a servizos web remotos Flickr ou 23.
Comment[hu]=Egy eszköz képek exportálásához távoli Flickr és 23 webszolgáltatásokba.
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Flickr dan 23 jarak jauh.
Comment[is]=Verkfæri til að senda myndir á fjarlægar Flickr og 23 vefþjónustur.
Comment[it]=Uno strumento per esportare immagini ai servizi web remoti Flickr e 23.
Comment[ka]=პროგრამა სურათების დაშორებულ Flickr-ის da 23-ის ვებსერვისებზე გასატანად.
Comment[ko]=이미지를 원격 Flickr와 23 웹 서비스로 내보내는 도구.
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Flickr- en 23-webservice op afstand te exporteren.
Comment[nn]=Verktøy for eksport av bilete til Flickr- og 23-tenestene på nettet.
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnych usług sieciowych Flickr i 23.
Comment[pt]=Uma ferramenta para exportar imagens para os serviços Web remotos do Flickr e 23.
Comment[pt_BR]=Ferramenta para exportar imagens para o Flickr e 23.
Comment[ro]=Unealtă de exportat imagini într servicii web distante Flickr și 23
Comment[ru]=Инструмент для экспорта изображений в веб-службы Flickr и 23
Comment[sk]=Nástroj na export obrázkov do webových služieb Flickr a 23.
Comment[sl]=Orodje za izvoz slik v oddaljeni spletni storitvi Flickr in 23.
Comment[sv]=Ett verktyg för att exportera bilder till webbtjänsterna Flickr eller 23.
Comment[tr]=Görselleri Flickr ve 23 web servisine aktarmak için bir araç.
Comment[uk]=Інструмент для експорту зображень до віддалених служб Flickr та 23.
Comment[x-test]=xxA tool to export images to remote Flickr and 23 web services.xx
Comment[zh_CN]=一个将图像导出到 Flickr、23 或 Zooomr 网络服务的工具。
Comment[zh_TW]=匯出圖片到遠端 Flickr 和 23 網路服務的工具
Type=Service
Icon=kipi-flickr
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flickr
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Vardhman Jain, vardhman at gmail dot com

==> kipi-plugins-23.07.90.tar.xz: kipi-plugins-23.07.90/flickr/kipiplugin_flickr.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flickr/23
Name=Flickr/23
Name[bg]=Flickr/23
Name[ca]=Flickr/23
Name[ca@valencia]=Flickr/23
Name[cs]=Flickr/23
Name[da]=Flickr/23
Name[de]=Flickr/23
Name[el]=Flickr/23
Name[en_GB]=Flickr/23
Name[es]=Flickr/23
Name[et]=Flickr/23
Name[eu]=Flickr/23
Name[fi]=Flickr/23
Name[fr]=Flickr/23
Name[gl]=Flickr/23
Name[hu]=Flickr/23
Name[ia]=Flickr/23
Name[id]=Flickr/23
Name[is]=Flickr/23
Name[it]=Flickr/23
Name[ka]=Flickr/23
Name[ko]=Flickr/23
Name[nl]=Flickr/23
Name[nn]=Flickr/23
Name[pl]=Flickr/23
Name[pt]=Flickr/23
Name[pt_BR]=Flickr/23
Name[ro]=Flickr/23
Name[ru]=Flickr/23
Name[sk]=Flickr/23
Name[sl]=Flickr/23
Name[sv]=Flickr/23
Name[tr]=Flickr/23
Name[uk]=Flickr/23
Name[x-test]=xxFlickr/23xx
Name[zh_CN]=Flickr/23
Name[zh_TW]=Flickr/23
Comment=A tool to export images to remote Flickr and 23 web services.
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Flickr, 23.
Comment[ca]=Una eina per a exportar les imatges als serveis web remots de Flickr i 23.
Comment[ca@valencia]=Una eina per a exportar les imatges als serveis web remots de Flickr i 23.
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Flickr a 23.
Comment[da]=Et værktøj til at eksportere billeder til eksterne Flickr og 23 webtjenester.
Comment[de]=Ein Werkzeug, um Bilder zum Flickr- oder 23- Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στις απομακρυσμένες υπηρεσίες ιστού Flickr και 23.
Comment[en_GB]=A tool to export images to remote Flickr and 23 web services.
Comment[es]=Una herramienta para exportar imágenes a los servicios web remotos de Flickr y 23.
Comment[et]=Tööriist piltide eksportimiseks Flickri ja 23 veebiteenusesse.
Comment[eu]=Irudiak urruneko Flickr eta 23 web zerbitzuetara esportatzeko tresna bat.
Comment[fi]=Työkalu kuvien viemiseksi Flickr- tai 23-etäverkkopalveluun.
Comment[fr]=Un outil pour l'export d'images vers les services en ligne Flickr et 23.
Comment[gl]=Unha ferramenta para exportar imaxes a servizos web remotos Flickr ou 23.
Comment[hu]=Egy eszköz képek exportálásához távoli Flickr és 23 webszolgáltatásokba.
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Flickr dan 23 jarak jauh.
Comment[is]=Verkfæri til að senda myndir á fjarlægar Flickr og 23 vefþjónustur.
Comment[it]=Uno strumento per esportare immagini ai servizi web remoti Flickr e 23.
Comment[ka]=პროგრამა სურათების დაშორებულ Flickr-ის da 23-ის ვებსერვისებზე გასატანად.
Comment[ko]=이미지를 원격 Flickr와 23 웹 서비스로 내보내는 도구.
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Flickr- en 23-webservice op afstand te exporteren.
Comment[nn]=Verktøy for eksport av bilete til Flickr- og 23-tenestene på nettet.
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnych usług sieciowych Flickr i 23.
Comment[pt]=Uma ferramenta para exportar imagens para os serviços Web remotos do Flickr e 23.
Comment[pt_BR]=Ferramenta para exportar imagens para o Flickr e 23.
Comment[ro]=Unealtă de exportat imagini într servicii web distante Flickr și 23
Comment[ru]=Инструмент для экспорта изображений в веб-службы Flickr и 23
Comment[sk]=Nástroj na export obrázkov do webových služieb Flickr a 23.
Comment[sl]=Orodje za izvoz slik v oddaljeni spletni storitvi Flickr in 23.
Comment[sv]=Ett verktyg för att exportera bilder till webbtjänsterna Flickr eller 23.
Comment[tr]=Görselleri Flickr ve 23 web hizmetine dışa aktarmak için bir araç.
Comment[uk]=Інструмент для експорту зображень до віддалених служб Flickr та 23.
Comment[x-test]=xxA tool to export images to remote Flickr and 23 web services.xx
Comment[zh_CN]=一个将图像导出到 Flickr、23 或 Zooomr 网络服务的工具。
Comment[zh_TW]=匯出圖片到遠端 Flickr 和 23 網路服務的工具
Type=Service
Icon=kipi-flickr
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flickr
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Vardhman Jain, vardhman at gmail dot com
